try:
    from wizzi_utils.algorithms.algorithms import *
except ModuleNotFoundError as e:
    pass

from wizzi_utils.algorithms import test
